Placing of maximum and minimum minor ticks
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Calculation of minor tick locations has been corrected to make the maximum and
minimum minor ticks more consistent.  In some cases this results in an extra
minor tick on an Axis.
